@@ -112,6 +112,8 @@ time = ""
 commandset = ""
 alwaysrun = ""
 alwaysrunset = []
+azurealwaysrun = ""
+azurealwaysrunset = []
 
 def find(name):
     currentdir = (
@@ -622,6 +624,29 @@ def execute_tests(testlist, testset):
     echo(os.getcwd())
     push_results()
 
+def get_always_tests_azure():
+    print("getting azure tests set to always run")
+    count = 0
+    tests = ""
+    for testName in azurealwaysrunset:
+        count = count + 1
+        if encodetests == "true":
+            testName = testName.encode("unicode_escape").decode()
+            testName = testName.replace("\\", "\\\\")
+            testName = strip_non_ascii(testName)
+            # testtoadd = testtoadd.replace("\\u00F6", "")
+            testName = testName.replace("\n", "\\n")
+            testName = testName.replace("(", "\(")
+            testName = testName.replace(")", "\)")
+            testName = testName.replace("&", "\&")
+            testName = testName.replace("|", "\|")
+            testName = testName.replace("=", "\=")
+            testName = testName.replace("!", "\!")
+            testName = testName.replace("~", "\~")
+        
+        tests = tests + testseparator + prefixtest + testName + postfixtest
+    return tests
+
 
 def get_tests(testpriority):
     echo("getting test set " + str(testpriority))
@@ -1190,6 +1215,7 @@ def runtestswithappsurify(*args):
         global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
         global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun, trainer, azure_variable, pipeoutput, recursive, bitrise, executioncommand, githubactionsvariable, printcommand
         global azurefilter, replaceretry, webdriverio, percentage, endspecificrun, runnewtests, weekendrunall, newdays, azurefilteronall, azurevariablenum, time, commandset, alwaysrun, alwaysrunset
+        global azurealwaysrun, azurealwaysrunset
 
         tests = ""
         testsrun = ""
@@ -1273,6 +1299,8 @@ def runtestswithappsurify(*args):
         commandset = ""
         alwaysrun = ""
         alwaysrunset = []
+        azurealwaysrun = ""
+        azurealwaysrunset = []
         # --testsuitesnameseparator and classnameseparator need to be encoded i.e. # is %23
 
         # Templates
@@ -1960,6 +1988,10 @@ def runtestswithappsurify(*args):
                     alwaysrun = argv[k + 1]
                     if alwaysrun.lower() != "none":
                         alwaysrunset = [x.strip() for x in alwaysrun.split(',')]
+                if argv[k] == "--azurealwaysrun":
+                    azurealwaysrun = argv[k + 1]
+                    if azurealwaysrun.lower() != "none":
+                        azurealwaysrunset = [x.strip() for x in azurealwaysrun.split(',')]
                 if argv[k] == "--runcommand":
                     commandset = argv[k + 1]
                     startrunall = argv[k + 1]
@@ -2239,6 +2271,7 @@ def runtestswithappsurify(*args):
                         f"##vso[task.setvariable variable={azure_variable}]{azurefilter}({testsrun})"
                     )
                 azuresets = []
+                azurealwaysruntestsformatted = get_always_tests_azure()
                 while len(testsrun) > max_length:
                     split_string = testsrun.find("|Name=", max_length)
                     setval = testsrun[:split_string]
@@ -2254,7 +2287,7 @@ def runtestswithappsurify(*args):
                 if testsrun.startswith("|"):
                     testsrun = testsrun[1:]
                 print(
-                    f"##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({testsrun})"
+                    f"##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}({testsrun}){azurealwaysruntestsformatted}"
                 )
                 testsettoappend = azurefilter + "(" + testsrun + ")"
                 azuresets.append(testsettoappend)
@@ -2263,7 +2296,7 @@ def runtestswithappsurify(*args):
                     print(f"Setting main variable to varialbe num {azurevariablenum}")
                     azurefilter = azuresets[int(azurevariablenum) - 1]
                     print(
-                        f"##vso[task.setvariable variable={azure_variable}]{azurefilter}"
+                        f"##vso[task.setvariable variable={azure_variable}]{azurefilter}{azurealwaysruntestsformatted}"
                     )
         # print("##vso[task.setvariable variable=BuildVersion;]998")
 
